@@ -33,9 +33,10 @@ typedef struct {
 	SoupAuth          *auth, *proxy_auth;
 	SoupConnection    *connection;
 
-	GSList            *disabled_features;
+	GHashTable        *disabled_features;
 
 	SoupURI           *first_party;
+	SoupURI           *site_for_cookies;
 
 	GTlsCertificate      *tls_certificate;
 	GTlsCertificateFlags  tls_errors;
@@ -43,6 +44,8 @@ typedef struct {
 	SoupRequest       *request;
 
 	SoupMessagePriority priority;
+
+	gboolean is_top_level_navigation;
 } SoupMessagePrivate;
 
 void             soup_message_cleanup_response (SoupMessage      *msg);
@@ -141,7 +144,7 @@ GInputStream *soup_message_io_get_response_istream (SoupMessage  *msg,
 gboolean soup_message_disables_feature (SoupMessage *msg,
 					gpointer     feature);
 
-GSList *soup_message_get_disabled_features (SoupMessage *msg);
+GList *soup_message_get_disabled_features (SoupMessage *msg);
 
 void soup_message_set_https_status (SoupMessage    *msg,
 				    SoupConnection *conn);
